nlsq.streaming_config module
=============================

Configuration for streaming optimizer with fault tolerance support.

.. automodule:: nlsq.streaming.config
   :members:
   :noindex:
   :undoc-members:
   :show-inheritance:
